==> mgpcli-0.1.72.tar.gz: README-zh.md <==
![](workflow/doc/images/logo-small.png)

[English](README.md) [中文说明](README-zh.md)

# Magpie Workflow

- [使用说明](#使用说明)
- [开发贡献](#开发贡献)
- [LICENSE](#license)

---

**Magpie Workflow**是一个Flutter开发的工具流，实现独立Flutter模块的创建，开发，编译，打包，上传流程；

整体包含三部分：
* 脚手架：命令行工具，如创建工程，启动可视化界面等
* workflow前端： 开发编译的可视化页面
* workflow后端： 为前端提供服务的server

![](workflow/doc/images/workflow-preview.gif)

## 使用说明

### 脚手架安装

确保您安装并正确配置了flutter环境

#### a. macOS环境变量配置
flutter环境变量配置
```
export PATH=/*flutter directory*/flutter/bin:$PATH
```

同时建议配置`dart`相关的环境变量，方便`pub`的使用

```
export PATH="/*flutter directory*/flutter/bin/cache/dart-sdk/bin:$PATH"
export PATH="$PATH":"$HOME/.pub-cache/bin"
```
#### b. Windows环境变量配置
flutter环境变量配置，在用户变量中选择`PATH`，双击后在末尾增加如下配置
```
\*flutter directory*\flutter\bin;
```
同时建议配置`dart`相关的环境变量，方便`pub`的使用
```
\*flutter directory*\flutter\bin\cache\dart-sdk\bin;
C:\Users\{替换用户名}\AppData\Roaming\Pub\Cache\bin
```

通过如上环境配置后，再运行pub命令安装mgpcli脚手架 (如何让环境变量生效 --- 可以关闭原有终端窗口再重新打开新终端)
(如果使用flutter pub安装，需要替换上面Pub-Cache的路径为flutter安装路径)

```shell
pub global activate mgpcli
```

脚手架的开发/编译，请参考[mgpcli 脚手架](CLI.md)

### workflow使用

通过`mgpcli`命令工具可以创建一个flutter项目，并启动worklow进行编译。

1.创建flutter模块工程

```shell
# 创建模板工程
mgpcli create -n flutter_sample
```

2.启动workflow

```shell
# 进入新创建的工程目录内
cd flutter_sample
# 启动workflow
mgpcli start
```

3.进入workflow

**现在已经为您打开了一个浏览器窗口**，请移步至窗口进行：[编译、Attach](http://127.0.0.1:8080)

## 开发贡献
源码开发和编译，根据模块不同请参考对应文档：
* CLi部分，请参考[脚手架](CLI.md)
* Workflow部分，请参考[Workflow](workflow/README.md)

## LICENSE

Magpie项目基于BSD协议开源，协议文件位于[LICENSE](LICENSE)。

==> mgpcli-0.1.74.tar.gz: README-zh.md <==
![](workflow/doc/images/logo-small.png)

[English](README.md) [中文说明](README-zh.md)

# Magpie Workflow

- [使用说明](#使用说明)
- [开发贡献](#开发贡献)
- [LICENSE](#license)

---

Magpie Workflow 是一个Flutter开发的工具流，实现独立Flutter模块的创建，开发，编译，打包，上传流程。
Magpie Workflow is a visualized platform which designed to create, develop and compile your 
standalone flutter module.

希望通过这种方式来简化Flutter混合开发的复杂度，成为连接开发者与Flutter的桥梁，因此取名为Magpie Workflow。项目整体包含三部分：

* 脚手架：命令行工具，如创建工程，启动可视化界面等
* workflow前端： 开发编译的可视化页面
* workflow后端： 为前端提供服务的server

![](workflow/doc/images/workflow-preview.gif)

## 使用说明

### 脚手架安装

确保您安装并正确配置了flutter环境，flutter版本支持**1.12.x**。

#### a. macOS环境变量配置
flutter环境变量配置
```
export PATH=/*flutter directory*/flutter/bin:$PATH
```

同时建议配置`dart`相关的环境变量，方便`pub`的使用

```
export PATH="/*flutter directory*/flutter/bin/cache/dart-sdk/bin:$PATH"
export PATH="$PATH":"$HOME/.pub-cache/bin"
```
#### b. Windows环境变量配置
flutter环境变量配置，在用户变量中选择`PATH`，双击后在末尾增加如下配置
```
\*flutter directory*\flutter\bin;
```
同时建议配置`dart`相关的环境变量，方便`pub`的使用
```
\*flutter directory*\flutter\bin\cache\dart-sdk\bin;
C:\Users\{替换用户名}\AppData\Roaming\Pub\Cache\bin
```

通过如上环境配置后，再运行pub命令安装mgpcli脚手架 (如何让环境变量生效 --- 可以关闭原有终端窗口再重新打开新终端)
(如果使用flutter pub安装，需要替换上面Pub-Cache的路径为flutter安装路径)

```shell
pub global activate mgpcli
```

脚手架的开发/编译，请参考[mgpcli 脚手架](CLI.md)

### workflow使用

通过`mgpcli`命令工具可以创建一个flutter项目，并启动workflow进行编译。

1.创建flutter模块工程

```shell
# 创建模板工程
mgpcli create -n flutter_sample
```

2.启动workflow

```shell
# 进入新创建的工程目录内
cd flutter_sample
# 启动workflow
mgpcli start
```

3.进入workflow

**现在已经为您打开了一个浏览器窗口**，请移步至窗口进行：[编译、Attach](http://127.0.0.1:8080)

## 开发贡献
源码开发和编译，根据模块不同请参考对应文档：
* CLi部分，请参考[脚手架](CLI.md)
* Workflow部分，请参考[Workflow](workflow/README.md)

## LICENSE

Magpie项目基于BSD协议开源，协议文件位于[LICENSE](LICENSE)。

## 关于我们

Magpie由58 Magpie技术团队开发/维护，项目离不开所有小伙伴们的积极参与(排序不分先后)：

[avenwu](https://github.com/avenwu), [CoCodeDZ](https://github.com/3aaap), [haijun](https://github.com/153493932), [hxinGood](https://github.com/hxinGood),  [iamagirlforios](https://github.com/iamagirlforios), [Kcwind](https://github.com/Kcwind), [lyx0224](https://github.com/lyx0224), [MuYuLi](https://github.com/MuYuLi), [xiubojin](https://github.com/xiubojin), [zdl51go](https://github.com/zdl51go),  [zhangkaixiao23](https://github.com/zhangkaixiao23)

感谢Alina_0516提供的设计支持。
